@@ -47,12 +47,12 @@
 
 + (GSPdf *)gspdf;
 
-- (BOOL)openDocumentForPath:(NSString *)path;
+//- (BOOL)openDocumentForPath:(NSString *)path;
 
 /** return the current GhostScript executable path */
 - (NSString *)gsPath;
 
-- (void)openFile:(id)sender;
+//- (void)openFile:(id)sender;
 
 - (void)documentHasClosed:(GSPdfDocument *)doc;
 
@@ -69,6 +69,8 @@
 - (IBAction)prefSave:(id)sender;
 - (IBAction)prefCancel:(id)sender;
 - (IBAction)chooseGsPath:(id)sender;
+- (IBAction)previousPage:(id)sender;
+- (IBAction)nextPage:(id)sender;
 
 - (void)runInfoPanel:(id)sender;
 
