@@ -2,7 +2,9 @@
  *  GSPdfDocument.h: Interface and declarations for the GSPdfDocument 
  *  Class of the GNUstep GSPdf application
  *
- *  Copyright (c) 2002 Enrico Sersale <enrico@imago.ro>
+ *  Copyright (c) 2002-2010
+ *  Riccardo Mottola
+ *  Enrico Sersale <enrico@imago.ro>
  *  
  *  Author: Enrico Sersale
  *  Date: February 2002
@@ -29,55 +31,45 @@
 @class GSPdfDocWin;
 @class PSDocument;
 @class PSDocumentPage;
-@class GSPdfImView;
 @class GSPdf;
 @class GSConsole;
 
-@interface GSPdfDocument : NSObject
+@interface GSPdfDocument : NSDocument
 {
-	NSString *myPath;
-	NSString *myName;
-	PSDocument *psdoc;
-	int pageindex;
-	float resolution;
-	int pagew, pageh;
-	NSSize papersize;
-	BOOL isPdf;
-	GSPdfDocWin *docwin;	
-	NSWindow *window;
-	NSScrollView *scroll;
-	GSPdfImView *imageView;
-	NSButton *leftButt, *rightButt;
-	NSScrollView *matrixScroll;
-	NSMatrix *pagesMatrix;
-	NSTextField *zoomField;
-	NSStepper *zoomStepper;
-	NSButton *zoomButt;
-	NSButton *handButt;
-	NSString *gsComm;
-	NSTask *task;
-	BOOL busy;	
-	NSFileManager *fm;
-	NSNotificationCenter *nc;	
-	GSPdf *gspdf;
-	GSConsole *console;
+  NSScrollView *matrixScroll;
+  NSMatrix *pagesMatrix;
+
+  GSConsole *console;
+
+  NSString *myPath;
+  PSDocument *psdoc;
+  int pageindex;
+  float resolution;
+  int pagew, pageh;
+  NSSize papersize;
+  BOOL isPdf;
+  GSPdfDocWin *docwin; /* window controller */  
+  NSString *gsComm;
+  NSTask *task;
+  BOOL busy;	
+  NSFileManager *fm;
+  NSNotificationCenter *nc;	
+  GSPdf *gspdf;
+  
 }
 
-- (id)initForPath:(NSString *)apath;
+- (NSString *)myPath;
 
--	(NSString *)myPath;
+- (BOOL)isPdf;
 
--	(BOOL)isPdf;
-
-- (void)nextPage:(id)sender;
-
-- (void)previousPage:(id)sender;
+- (void)nextPage;
+- (void)previousPage;
+- (void)regeneratePage;
 
 - (void)goToPage:(id)sender;
 
 - (void)makePage;
-
-- (void)setZoomValue:(id)sender;
+- (void)setZoomValue:(int)value;
 
 - (void)setPaperSize:(id)sender;
 
